import React from 'react'
import plusSecondary from '~/images/plus-secondary.svg'
import minusGray from '~/images/minus-gray.svg'

interface Props {
  isBgWhite?: boolean
}

export default function AccordionTemplate(props: Props) {
  const [activeIndex, setActiveIndex] = React.useState<number | null>(null)

  const handleToggle = (index: number) => {
    setActiveIndex(activeIndex === index ? null : index) // Aynı accordion'a basılırsa kapat
  }

  return (
    <>
      {[...Array(8)].map((_, i) => (
        <div key={i}>
          <Accordion
            label="Puanlarımı nasıl kazanırım?"
            isOpen={activeIndex === i}
            onToggle={() => handleToggle(i)}
            {...props}
          >
            Benim Ustam programına üye olduktan sonra, her orijinal parça alışverişinizde puan
            kazanabilirsiniz. Orijinal parça satın alarak faturayı sisteme yükleyin, puanlarınız
            otomatik yüklensin ve biriken puanlarınızı dilediğiniz gibi harcayın! 🎁
          </Accordion>
        </div>
      ))}
    </>
  )
}

interface AccordionProps extends Props {
  label: string
  children: React.ReactNode
  isOpen: boolean
  onToggle: () => void
}

function Accordion({ label, children, isOpen, onToggle, isBgWhite }: AccordionProps) {
  return (
    <div className={`rounded-2xl p-4 xl:p-6 ${isOpen ? 'shadow-xl bg-white' : `${isBgWhite ? 'bg-white' : ''} border border-gray-200`}`}>
      <div onClick={onToggle} className="flex items-center justify-between cursor-pointer">
        <h3 className="font-semibold text-xl">{label}</h3>
        <img src={isOpen ? minusGray : plusSecondary} width={24} height={24} alt="" />
      </div>
      {isOpen && <div className="mt-4 border-t border-gray-200 pt-4">{children}</div>}
    </div>
  )
}
